@@ -20,61 +20,61 @@ from monty.shutil import (
     remove,
 )
 
-test_dir = os.path.join(os.path.dirname(__file__), "test_files")
+TEST_DIR = os.path.join(os.path.dirname(__file__), "test_files")
 
 
 class TestCopyR:
     def setup_method(self):
-        os.mkdir(os.path.join(test_dir, "cpr_src"))
+        os.mkdir(os.path.join(TEST_DIR, "cpr_src"))
         with open(
-            os.path.join(test_dir, "cpr_src", "test"), "w", encoding="utf-8"
+            os.path.join(TEST_DIR, "cpr_src", "test"), "w", encoding="utf-8"
         ) as f:
             f.write("what")
-        os.mkdir(os.path.join(test_dir, "cpr_src", "sub"))
+        os.mkdir(os.path.join(TEST_DIR, "cpr_src", "sub"))
         with open(
-            os.path.join(test_dir, "cpr_src", "sub", "testr"), "w", encoding="utf-8"
+            os.path.join(TEST_DIR, "cpr_src", "sub", "testr"), "w", encoding="utf-8"
         ) as f:
             f.write("what2")
-        if os.name != "nt":
+        if platform.system() != "Windows":
             os.symlink(
-                os.path.join(test_dir, "cpr_src", "test"),
-                os.path.join(test_dir, "cpr_src", "mysymlink"),
+                os.path.join(TEST_DIR, "cpr_src", "test"),
+                os.path.join(TEST_DIR, "cpr_src", "mysymlink"),
             )
 
     def test_recursive_copy_and_compress(self):
-        copy_r(os.path.join(test_dir, "cpr_src"), os.path.join(test_dir, "cpr_dst"))
-        assert os.path.exists(os.path.join(test_dir, "cpr_dst", "test"))
-        assert os.path.exists(os.path.join(test_dir, "cpr_dst", "sub", "testr"))
+        copy_r(os.path.join(TEST_DIR, "cpr_src"), os.path.join(TEST_DIR, "cpr_dst"))
+        assert os.path.exists(os.path.join(TEST_DIR, "cpr_dst", "test"))
+        assert os.path.exists(os.path.join(TEST_DIR, "cpr_dst", "sub", "testr"))
 
-        compress_dir(os.path.join(test_dir, "cpr_src"))
-        assert os.path.exists(os.path.join(test_dir, "cpr_src", "test.gz"))
-        assert os.path.exists(os.path.join(test_dir, "cpr_src", "sub", "testr.gz"))
+        compress_dir(os.path.join(TEST_DIR, "cpr_src"))
+        assert os.path.exists(os.path.join(TEST_DIR, "cpr_src", "test.gz"))
+        assert os.path.exists(os.path.join(TEST_DIR, "cpr_src", "sub", "testr.gz"))
 
-        decompress_dir(os.path.join(test_dir, "cpr_src"))
-        assert os.path.exists(os.path.join(test_dir, "cpr_src", "test"))
-        assert os.path.exists(os.path.join(test_dir, "cpr_src", "sub", "testr"))
-        with open(os.path.join(test_dir, "cpr_src", "test"), encoding="utf-8") as f:
+        decompress_dir(os.path.join(TEST_DIR, "cpr_src"))
+        assert os.path.exists(os.path.join(TEST_DIR, "cpr_src", "test"))
+        assert os.path.exists(os.path.join(TEST_DIR, "cpr_src", "sub", "testr"))
+        with open(os.path.join(TEST_DIR, "cpr_src", "test"), encoding="utf-8") as f:
             txt = f.read()
             assert txt == "what"
 
     def test_pathlib(self):
-        test_path = Path(test_dir)
+        test_path = Path(TEST_DIR)
         copy_r(test_path / "cpr_src", test_path / "cpr_dst")
         assert (test_path / "cpr_dst" / "test").exists()
         assert (test_path / "cpr_dst" / "sub" / "testr").exists()
 
     def teardown_method(self):
-        shutil.rmtree(os.path.join(test_dir, "cpr_src"))
-        shutil.rmtree(os.path.join(test_dir, "cpr_dst"))
+        shutil.rmtree(os.path.join(TEST_DIR, "cpr_src"))
+        shutil.rmtree(os.path.join(TEST_DIR, "cpr_dst"))
 
 
 class TestCompressFileDir:
     def setup_method(self):
-        with open(os.path.join(test_dir, "tempfile"), "w", encoding="utf-8") as f:
+        with open(os.path.join(TEST_DIR, "tempfile"), "w", encoding="utf-8") as f:
             f.write("hello world")
 
     def test_compress_and_decompress_file(self):
-        fname = os.path.join(test_dir, "tempfile")
+        fname = os.path.join(TEST_DIR, "tempfile")
 
         for fmt in ["gz", "bz2"]:
             compress_file(fname, fmt)
@@ -97,8 +97,8 @@ class TestCompressFileDir:
         assert decompress_file("non-existent.bz2") is None
 
     def test_compress_and_decompress_with_target_dir(self):
-        fname = os.path.join(test_dir, "tempfile")
-        target_dir = os.path.join(test_dir, "temp_target_dir")
+        fname = os.path.join(TEST_DIR, "tempfile")
+        target_dir = os.path.join(TEST_DIR, "temp_target_dir")
 
         for fmt in ["gz", "bz2"]:
             compress_file(fname, fmt, target_dir)
@@ -121,22 +121,22 @@ class TestCompressFileDir:
                 assert f.read() == "hello world"
 
     def teardown_method(self):
-        os.remove(os.path.join(test_dir, "tempfile"))
+        os.remove(os.path.join(TEST_DIR, "tempfile"))
 
 
 class TestGzipDir:
     def setup_method(self):
-        os.mkdir(os.path.join(test_dir, "gzip_dir"))
+        os.mkdir(os.path.join(TEST_DIR, "gzip_dir"))
         with open(
-            os.path.join(test_dir, "gzip_dir", "tempfile"), "w", encoding="utf-8"
+            os.path.join(TEST_DIR, "gzip_dir", "tempfile"), "w", encoding="utf-8"
         ) as f:
             f.write("what")
 
-        self.mtime = os.path.getmtime(os.path.join(test_dir, "gzip_dir", "tempfile"))
+        self.mtime = os.path.getmtime(os.path.join(TEST_DIR, "gzip_dir", "tempfile"))
 
     def test_gzip_dir(self):
-        full_f = os.path.join(test_dir, "gzip_dir", "tempfile")
-        gzip_dir(os.path.join(test_dir, "gzip_dir"))
+        full_f = os.path.join(TEST_DIR, "gzip_dir", "tempfile")
+        gzip_dir(os.path.join(TEST_DIR, "gzip_dir"))
 
         assert os.path.exists(f"{full_f}.gz")
         assert not os.path.exists(full_f)
@@ -148,7 +148,7 @@ class TestGzipDir:
 
     def test_gzip_dir_file_coexist(self):
         """Test case where both file and file.gz exist."""
-        full_f = os.path.join(test_dir, "gzip_dir", "temptestfile")
+        full_f = os.path.join(TEST_DIR, "gzip_dir", "temptestfile")
         gz_f = f"{full_f}.gz"
 
         # Create both the file and its gzipped version
@@ -160,7 +160,7 @@ class TestGzipDir:
         with pytest.warns(
             UserWarning, match="Both temptestfile and temptestfile.gz exist."
         ):
-            gzip_dir(os.path.join(test_dir, "gzip_dir"))
+            gzip_dir(os.path.join(TEST_DIR, "gzip_dir"))
 
         # Verify contents of the files
         with open(full_f, "r", encoding="utf-8") as f:
@@ -170,13 +170,13 @@ class TestGzipDir:
             assert g.read() == b"gzipped"
 
     def test_handle_sub_dirs(self):
-        sub_dir = os.path.join(test_dir, "gzip_dir", "sub_dir")
+        sub_dir = os.path.join(TEST_DIR, "gzip_dir", "sub_dir")
         sub_file = os.path.join(sub_dir, "new_tempfile")
         os.mkdir(sub_dir)
         with open(sub_file, "w", encoding="utf-8") as f:
             f.write("anotherwhat")
 
-        gzip_dir(os.path.join(test_dir, "gzip_dir"))
+        gzip_dir(os.path.join(TEST_DIR, "gzip_dir"))
 
         assert os.path.exists(f"{sub_file}.gz")
         assert not os.path.exists(sub_file)
@@ -185,13 +185,13 @@ class TestGzipDir:
             assert g.readline().decode("utf-8") == "anotherwhat"
 
     def teardown_method(self):
-        shutil.rmtree(os.path.join(test_dir, "gzip_dir"))
+        shutil.rmtree(os.path.join(TEST_DIR, "gzip_dir"))
 
 
 class TestRemove:
     @unittest.skipIf(platform.system() == "Windows", "Skip on windows")
     def test_remove_file(self):
-        tempdir = tempfile.mkdtemp(dir=test_dir)
+        tempdir = tempfile.mkdtemp(dir=TEST_DIR)
         tempf = tempfile.mkstemp(dir=tempdir)[1]
         remove(tempf)
         assert not os.path.isfile(tempf)
@@ -199,17 +199,17 @@ class TestRemove:
 
     @unittest.skipIf(platform.system() == "Windows", "Skip on windows")
     def test_remove_folder(self):
-        tempdir = tempfile.mkdtemp(dir=test_dir)
+        tempdir = tempfile.mkdtemp(dir=TEST_DIR)
         remove(tempdir)
         assert not os.path.isdir(tempdir)
 
     @unittest.skipIf(platform.system() == "Windows", "Skip on windows")
     def test_remove_symlink(self):
-        tempdir = tempfile.mkdtemp(dir=test_dir)
+        tempdir = tempfile.mkdtemp(dir=TEST_DIR)
         tempf = tempfile.mkstemp(dir=tempdir)[1]
 
-        os.symlink(tempdir, os.path.join(test_dir, "temp_link"))
-        templink = os.path.join(test_dir, "temp_link")
+        os.symlink(tempdir, os.path.join(TEST_DIR, "temp_link"))
+        templink = os.path.join(TEST_DIR, "temp_link")
         remove(templink)
         assert os.path.isfile(tempf)
         assert os.path.isdir(tempdir)
@@ -218,11 +218,11 @@ class TestRemove:
 
     @unittest.skipIf(platform.system() == "Windows", "Skip on windows")
     def test_remove_symlink_follow(self):
-        tempdir = tempfile.mkdtemp(dir=test_dir)
+        tempdir = tempfile.mkdtemp(dir=TEST_DIR)
         tempf = tempfile.mkstemp(dir=tempdir)[1]
 
-        os.symlink(tempdir, os.path.join(test_dir, "temp_link"))
-        templink = os.path.join(test_dir, "temp_link")
+        os.symlink(tempdir, os.path.join(TEST_DIR, "temp_link"))
+        templink = os.path.join(TEST_DIR, "temp_link")
         remove(templink, follow_symlink=True)
         assert not os.path.isfile(tempf)
         assert not os.path.isdir(tempdir)
